pub struct PluginManifest {
pub name: String,
pub version: String,
pub abi_version: u32,
pub boundary: PluginBoundary,
pub capabilities: Vec<String>,
pub limits: ResourceLimits,
}Fields
name: Stringversion: Stringabi_version: u32boundary: PluginBoundarycapabilities: Vec<String>limits: ResourceLimitsImplementations
Sourceimpl PluginManifest
impl PluginManifest
pub fn process(name: impl Into<String>, version: impl Into<String>) -> Self
pub fn with_capability(self, capability: impl Into<String>) -> Self
pub const fn with_limits(self, limits: ResourceLimits) -> Self
Sourcepub const fn validate(&self) -> Result<(), PluginAuthorizationError>
pub const fn validate(&self) -> Result<(), PluginAuthorizationError>
Errors
Returns an error when the manifest is empty or targets another ABI.
Sourcepub fn validate_request(
&self,
request: &ToolRequest,
) -> Result<(), PluginAuthorizationError>
pub fn validate_request( &self, request: &ToolRequest, ) -> Result<(), PluginAuthorizationError>
Errors
Returns an error when the manifest is invalid or a request needs a capability not declared by the plugin.