ToolEffect

Struct ToolEffect 

pub struct ToolEffect {
    pub kind: ToolEffectKind,
    pub target: String,
    pub reversibility: EffectReversibility,
    pub confirmation: EffectConfirmation,
    pub dry_run: DryRunSupport,
}
Declarative hints about how a tool participates in the runtime.

Fields

kind: ToolEffectKind

The stable effect category.

target: String

Optional target, such as a path, host, channel, or resource name.

reversibility: EffectReversibility

Whether this effect can be undone after execution.

confirmation: EffectConfirmation

Confirmation preference declared by the tool author.

dry_run: DryRunSupport

Dry-run support declared by the tool author.

Implementations

Source

impl ToolEffect

pub const fn new(kind: ToolEffectKind) -> Self

pub fn with_target(self, target: impl Into<String>) -> Self

pub const fn with_reversibility( self, reversibility: EffectReversibility, ) -> Self

pub const fn with_confirmation(self, confirmation: EffectConfirmation) -> Self

pub const fn with_dry_run(self, dry_run: DryRunSupport) -> Self

pub const fn is_mutating(&self) -> bool

pub fn label(&self) -> String