pub struct StatsResponse {Show 26 fields
pub current_seq: u64,
pub checkpoint_seq: u64,
pub live_segments: usize,
pub retired_segments: usize,
pub memtable_cells: usize,
pub memtable_versions: usize,
pub memtable_payload_bytes: usize,
pub estimated_memtable_bytes: usize,
pub estimated_index_bytes: usize,
pub estimated_context_pack_bytes: usize,
pub estimated_total_memory_bytes: usize,
pub live_segment_bytes: u64,
pub retired_segment_bytes: u64,
pub total_segment_bytes: u64,
pub durable_storage_bytes: u64,
pub live_segment_payload_bytes: u64,
pub logical_payload_bytes: u64,
pub space_amplification_q16: u32,
pub write_amplification_q16: u32,
pub compaction_pressure_q16: u32,
pub wal_size_bytes: u64,
pub wal_writer_records: u64,
pub wal_writer_bytes: u64,
pub wal_writer_fsyncs: u64,
pub wal_writer_batches: u64,
pub aql_query_cache: AqlQueryCacheStatsResponse,
}Expand description
Response metrics containing detailed storage, MemTable, and WAL statistics.
Fields
current_seq: u64The current global database commit sequence.
checkpoint_seq: u64The commit sequence of the last successful checkpoint.
live_segments: usizeThe number of active LSM-segments currently being queried.
retired_segments: usizeThe number of garbage-collected or retired segments on disk.
memtable_cells: usizeTotal number of unique knowledge cell IDs in MemTable.
memtable_versions: usizeTotal number of cell versions currently held in MemTable.
memtable_payload_bytes: usizeRaw payload bytes currently retained by MemTable versions.
estimated_memtable_bytes: usizeEstimated in-memory bytes used by MemTable structures and payloads.
estimated_index_bytes: usizeEstimated in-memory bytes used by query/index structures.
estimated_context_pack_bytes: usizeEstimated bytes needed to materialize a ContextPack working set.
estimated_total_memory_bytes: usizeEstimated total engine memory across tracked categories.
live_segment_bytes: u64Durable bytes held by live segment bundles.
retired_segment_bytes: u64Durable bytes held by retired segment bundles waiting for GC.
total_segment_bytes: u64Durable bytes held by all segment bundles.
durable_storage_bytes: u64Durable segment bytes plus active WAL bytes.
live_segment_payload_bytes: u64Payload bytes inside live segment cells.
logical_payload_bytes: u64Logical payload proxy used as the denominator for amplification metrics.
space_amplification_q16: u32Q16 durable-storage/logical-payload space amplification proxy.
write_amplification_q16: u32Q16 local durable-write/logical-payload amplification proxy.
compaction_pressure_q16: u32Q16 retired-segment/total-segment compaction pressure.
wal_size_bytes: u64Total size of the active Write-Ahead Log (.aclog) files in bytes.
wal_writer_records: u64Total number of transaction log records appended.
wal_writer_bytes: u64Total bytes appended to the active WAL file.
wal_writer_fsyncs: u64Total number of disk fsync flushes executed by the WAL writer.
wal_writer_batches: u64Total number of batches committed under group commit.
aql_query_cache: AqlQueryCacheStatsResponseAQL query-plan cache size, policy, and hit/miss counters.